# {{PACKAGE_TITLE}}

[![PyPI](https://img.shields.io/pypi/v/{{PYPI_PACKAGE}})](https://pypi.org/project/{{PYPI_PACKAGE}}/)

[![Python Test](https://github.com/fujiawei-dev/{{PYPI_PACKAGE}}/actions/workflows/python-test.yml/badge.svg)](https://github.com/fujiawei-dev/{{PYPI_PACKAGE}}/actions/workflows/python-test.yml)
[![Python Publish](https://github.com/fujiawei-dev/{{PYPI_PACKAGE}}/actions/workflows/python-publish.yml/badge.svg)](https://github.com/fujiawei-dev/{{PYPI_PACKAGE}}/actions/workflows/python-publish.yml)

## Installation

```shell
pip install -U {{PYPI_PACKAGE}}
```

```shell
pip install -U {{PYPI_PACKAGE}} -i https://pypi.douban.com/simple
```

## Usage

```shell

```
